@@ -2,7 +2,7 @@
 # This file is part of the bumpver project
 # https://github.com/mbarkhau/bumpver
 #
-# Copyright (c) 2018-2021 Manuel Barkhau (mbarkhau@gmail.com) - MIT License
+# Copyright (c) 2018-2022 Manuel Barkhau (mbarkhau@gmail.com) - MIT License
 # SPDX-License-Identifier: MIT
 """cli module for BumpVer."""
 import io
@@ -246,9 +246,8 @@ def version_options(function: typ.Callable) -> typ.Callable:
     return decorated
 
 
-@click.group()
-@click.version_option(version="2021.1114")
-@click.help_option()
+@click.group(context_settings={'help_option_names': ["-h", "--help"]})
+@click.version_option(version="2022.1118")
 @verbose_option
 def cli(verbose: int = 0) -> None:
     """Automatically update version strings in plaintext files."""
@@ -281,7 +280,7 @@ def test(
     raw_pattern = pattern  # use internal naming convention
 
     _validate_flags(raw_pattern, major, minor, patch)
-    _date = _validate_date(date, pin_date)
+    maybe_date = _validate_date(date, pin_date)
 
     if set_version is None:
         new_version = incr_dispatch(
@@ -293,7 +292,7 @@ def test(
             tag=tag,
             tag_num=tag_num,
             pin_date=pin_date,
-            date=_date,
+            maybe_date=maybe_date,
         )
     else:
         new_version = set_version
@@ -522,13 +521,13 @@ def incr_dispatch(
     old_version: str,
     raw_pattern: str,
     *,
-    major   : bool = False,
-    minor   : bool = False,
-    patch   : bool = False,
-    tag     : str = None,
-    tag_num : bool = False,
-    pin_date: bool = False,
-    date    : typ.Optional[dt.date] = None,
+    major     : bool = False,
+    minor     : bool = False,
+    patch     : bool = False,
+    tag       : str = None,
+    tag_num   : bool = False,
+    pin_date  : bool = False,
+    maybe_date: typ.Optional[dt.date] = None,
 ) -> typ.Optional[str]:
     v1_parts    = list(v1patterns.PART_PATTERNS) + list(v1patterns.FULL_PART_FORMATS)
     has_v1_part = any("{" + part + "}" in raw_pattern for part in v1_parts)
@@ -552,7 +551,7 @@ def incr_dispatch(
             tag=tag,
             tag_num=tag_num,
             pin_date=pin_date,
-            date=date,
+            maybe_date=maybe_date,
         )
     else:
         return v2version.incr(
@@ -564,7 +563,7 @@ def incr_dispatch(
             tag=tag,
             tag_num=tag_num,
             pin_date=pin_date,
-            date=date,
+            maybe_date=maybe_date,
         )
 
 
@@ -665,7 +664,7 @@ def _update_cfg_from_vcs(cfg: config.Config, fetch: bool) -> config.Config:
         return cfg
     else:
         latest_version_pep440 = version.to_pep440(latest_version_tag)
-        if latest_version_tag <= cfg.current_version:
+        if version.parse_version(latest_version_tag) <= version.parse_version(cfg.current_version):
             # current_version already newer/up-to-date
             return cfg
         else:
@@ -762,7 +761,7 @@ def update(
     verbose = max(_VERBOSE, verbose)
     _configure_logging(verbose)
     _validate_release_tag(tag)
-    _date = _validate_date(date, pin_date)
+    maybe_date = _validate_date(date, pin_date)
 
     _, cfg = config.init(project_path=".")
 
@@ -789,7 +788,7 @@ def update(
             tag=tag,
             tag_num=tag_num,
             pin_date=pin_date,
-            date=_date,
+            maybe_date=maybe_date,
         )
     else:
         new_version = set_version
