@@ -1,7 +1,7 @@
 # This file is part of the bumpver project
 # https://github.com/mbarkhau/bumpver
 #
-# Copyright (c) 2018-2021 Manuel Barkhau (mbarkhau@gmail.com) - MIT License
+# Copyright (c) 2018-2022 Manuel Barkhau (mbarkhau@gmail.com) - MIT License
 # SPDX-License-Identifier: MIT
 """Functions related to version string manipulation."""
 
@@ -381,13 +381,13 @@ def incr(
     old_version: str,
     raw_pattern: str = "{pycalver}",
     *,
-    major   : bool = False,
-    minor   : bool = False,
-    patch   : bool = False,
-    tag     : typ.Optional[str] = None,
-    tag_num : bool = False,
-    pin_date: bool = False,
-    date    : typ.Optional[dt.date] = None,
+    major     : bool = False,
+    minor     : bool = False,
+    patch     : bool = False,
+    tag       : typ.Optional[str] = None,
+    tag_num   : bool = False,
+    pin_date  : bool = False,
+    maybe_date: typ.Optional[dt.date] = None,
 ) -> typ.Optional[str]:
     """Increment version string.
 
@@ -399,6 +399,8 @@ def incr(
         logger.error(str(ex))
         return None
 
+    date = version.TODAY if maybe_date is None else maybe_date
+
     cur_cinfo = _ver_to_cal_info(old_vinfo) if pin_date else cal_info(date)
 
     if _is_cal_gt(old_vinfo, cur_cinfo):
