@@ -1,7 +1,7 @@
 # This file is part of the bumpver project
 # https://github.com/mbarkhau/bumpver
 #
-# Copyright (c) 2018-2021 Manuel Barkhau (mbarkhau@gmail.com) - MIT License
+# Copyright (c) 2018-2022 Manuel Barkhau (mbarkhau@gmail.com) - MIT License
 # SPDX-License-Identifier: MIT
 """Functions related to version string manipulation."""
 
@@ -35,20 +35,6 @@ def _is_cal_gt(left: CalInfo, right: CalInfo) -> bool:
     return lvals > rvals
 
 
-def _ver_to_cal_info(vinfo: version.V2VersionInfo) -> version.V2CalendarInfo:
-    return version.V2CalendarInfo(
-        vinfo.year_y,
-        vinfo.year_g,
-        vinfo.quarter,
-        vinfo.month,
-        vinfo.dom,
-        vinfo.doy,
-        vinfo.week_w,
-        vinfo.week_u,
-        vinfo.week_v,
-    )
-
-
 def cal_info(date: dt.date = None) -> version.V2CalendarInfo:
     """Generate calendar components for current date.
 
@@ -88,6 +74,21 @@ def cal_info(date: dt.date = None) -> version.V2CalendarInfo:
     return version.V2CalendarInfo(**kwargs)
 
 
+def _ver_to_cal_info(vinfo: version.V2VersionInfo) -> version.V2CalendarInfo:
+    defaults = cal_info(version.TODAY)
+    return version.V2CalendarInfo(
+        vinfo.year_y or defaults.year_y,
+        vinfo.year_g or defaults.year_g,
+        vinfo.quarter or defaults.quarter,
+        vinfo.month or defaults.month,
+        vinfo.dom or defaults.dom,
+        vinfo.doy or defaults.doy,
+        vinfo.week_w or defaults.week_w,
+        vinfo.week_u or defaults.week_u,
+        vinfo.week_v or defaults.week_v,
+    )
+
+
 VALID_FIELD_KEYS = set(version.V2VersionInfo._fields) | {'version'}
 
 MaybeInt = typ.Optional[int]
@@ -151,8 +152,14 @@ def parse_field_values_to_cinfo(field_values: FieldValues) -> version.V2Calendar
     if year_y and month and dom:
         date = dt.date(year_y, month, dom)
 
+    # Use of defaults is an all or nothing affair.
+    # We don't to mix anything from TODAY with stuff
+    # that was actually parsed from a string.
+    if not any((date, year_y, year_g, month, dom, doy, week_w, week_u, week_v)):
+        date = version.TODAY
+
+    # derive all fields from other previous values
     if date:
-        # derive all fields from other previous values
         year_y = int(date.strftime("%Y"), base=10)
         year_g = int(date.strftime("%G"), base=10)
         month  = int(date.strftime("%m"), base=10)
@@ -214,8 +221,9 @@ def parse_field_values_to_vinfo(field_values: FieldValues) -> version.V2VersionI
 
     fvals = field_values
 
-    tag   = fvals.get('tag'  ) or ""
-    pytag = fvals.get('pytag') or ""
+    tag     = fvals.get('tag'    ) or ""
+    pytag   = fvals.get('pytag'  ) or ""
+    githash = fvals.get('githash') or ""
 
     if tag and not pytag:
         pytag = version.PEP440_TAG_BY_TAG[tag]
@@ -250,6 +258,7 @@ def parse_field_values_to_vinfo(field_values: FieldValues) -> version.V2VersionI
         bid=bid,
         tag=tag,
         pytag=pytag,
+        githash=githash,
         num=num,
         inc0=inc0,
         inc1=inc1,
@@ -424,6 +433,10 @@ def _format_segment(seg: Segment, part_values: PartValues) -> FormatedSeg:
                 zero_part_count += 1
 
     result = seg
+    # remove regex chars
+    result = result.replace(r"^", r"")
+    result = result.replace(r"$", r"")
+
     # unescape braces
     result = result.replace(r"\[", r"[")
     result = result.replace(r"\]", r"]")
@@ -725,13 +738,13 @@ def incr(
     old_version: str,
     raw_pattern: str = "vYYYY0M.BUILD[-TAG]",
     *,
-    major   : bool = False,
-    minor   : bool = False,
-    patch   : bool = False,
-    tag     : typ.Optional[str] = None,
-    tag_num : bool = False,
-    pin_date: bool = False,
-    date    : typ.Optional[dt.date] = None,
+    major     : bool = False,
+    minor     : bool = False,
+    patch     : bool = False,
+    tag       : typ.Optional[str] = None,
+    tag_num   : bool = False,
+    pin_date  : bool = False,
+    maybe_date: typ.Optional[dt.date] = None,
 ) -> typ.Optional[str]:
     """Increment version string.
 
@@ -740,6 +753,8 @@ def incr(
     if not is_valid_week_pattern(raw_pattern):
         return None
 
+    date = version.TODAY if maybe_date is None else maybe_date
+
     try:
         old_vinfo = parse_version_info(old_version, raw_pattern)
     except version.PatternError as ex:
@@ -772,6 +787,7 @@ def incr(
     )
 
     new_version = format_version(cur_vinfo, raw_pattern)
+
     if new_version == old_version:
         logger.error("Invalid arguments or pattern, version did not change.")
         return None
