@@ -230,7 +230,7 @@ def test_v1_iter_rewritten():
         "# This file is part of the bumpver project",
         "# https://github.com/mbarkhau/bumpver",
         "#",
-        "# Copyright (c) 2018-2021 Manuel Barkhau (mbarkhau@gmail.com) - MIT License",
+        "# Copyright (c) 2018-2022 Manuel Barkhau (mbarkhau@gmail.com) - MIT License",
         "# SPDX-License-Identifier: MIT",
         '"""BumpVer: A CLI program for versioning."""',
         '',
@@ -256,7 +256,7 @@ def test_v2_iter_rewritten():
         "# This file is part of the bumpver project",
         "# https://github.com/mbarkhau/bumpver",
         "#",
-        "# Copyright (c) 2018-2021 Manuel Barkhau (mbarkhau@gmail.com) - MIT License",
+        "# Copyright (c) 2018-2022 Manuel Barkhau (mbarkhau@gmail.com) - MIT License",
         "# SPDX-License-Identifier: MIT",
         '"""BumpVer: A CLI program for versioning."""',
         '',
@@ -336,3 +336,11 @@ def test_v2_diff():
     lines = diff_str.split("\n")
     assert lines[3].startswith("-MIT License Copyright (c) 2018-20")
     assert lines[4].startswith("+MIT License Copyright (c) 2018-2019")
+
+
+def test_remove_regex_chars():
+    version_pattern = "YYYY.BUILD[-TAG]"
+    new_vinfo       = v2version.parse_version_info("2018.0123-beta", version_pattern)
+    patterns        = [v2patterns.compile_pattern(version_pattern, '^__version__ = "{version}"')]
+    lines           = v2rewrite.rewrite_lines(patterns, new_vinfo, ['__version__ = "2018.0002-alpha"   '])
+    assert lines == ['__version__ = "2018.0123-beta"   ']
